@@ -30,8 +30,11 @@
 #include <gnome-settings-daemon/gsd-enums.h>
 #include <math.h>
 
+#include <gdesktop-enums.h>
+
 #include "gnome-mouse-properties.h"
 #include "gsd-input-helper.h"
+#include "gsd-device-manager.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -49,16 +52,21 @@ struct _CcMousePropertiesPrivate
 	GtkBuilder *builder;
 
 	GSettings *mouse_settings;
+	GSettings *gsd_mouse_settings;
 	GSettings *touchpad_settings;
 
-	GdkDeviceManager *device_manager;
+	GsdDeviceManager *device_manager;
 	guint device_added_id;
 	guint device_removed_id;
 
+	gboolean have_mouse;
+	gboolean have_touchpad;
+	gboolean have_touchscreen;
+
 	gboolean changing_scroll;
 };
 
-G_DEFINE_TYPE (CcMouseProperties, cc_mouse_properties, GTK_TYPE_ALIGNMENT);
+G_DEFINE_TYPE (CcMouseProperties, cc_mouse_properties, GTK_TYPE_BIN);
 
 static void
 orientation_radio_button_release_event (GtkWidget   *widget,
@@ -92,11 +100,10 @@ scrollmethod_changed_event (GtkToggleButton *button, CcMousePropertiesPrivate *d
 		method = GSD_TOUCHPAD_SCROLL_METHOD_EDGE_SCROLLING;
 
 	g_settings_set_enum (d->touchpad_settings, "scroll-method", method);
-	g_settings_set_boolean (d->touchpad_settings, "horiz-scroll-enabled", TRUE);
 }
 
 static void
-synaptics_check_capabilities (CcMousePropertiesPrivate *d)
+synaptics_check_capabilities_x11 (CcMousePropertiesPrivate *d)
 {
 	int numdevices, i;
 	XDeviceInfo *devicelist;
@@ -145,48 +152,70 @@ synaptics_check_capabilities (CcMousePropertiesPrivate *d)
 }
 
 static void
-pointer_speed_scale_event (GtkRange *scale, CcMousePropertiesPrivate *d)
+synaptics_check_capabilities (CcMousePropertiesPrivate *d)
 {
-	gdouble value;
-	GSettings *settings;
-	GtkAdjustment *adjustment;
-
-	if (GTK_WIDGET (scale) == WID ("pointer_speed_scale"))
-		settings = d->mouse_settings;
-	else
-		settings = d->touchpad_settings;
-
-	adjustment = gtk_range_get_adjustment (scale);
-	value = gtk_adjustment_get_upper (adjustment) - gtk_range_get_value (scale) + 1;
-	g_settings_set_int (settings, "motion-threshold", value);
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+		synaptics_check_capabilities_x11 (d);
+	/* else we unconditionally show all touchpad knobs */
 }
 
 static gboolean
-show_touchpad_enabling_switch (GSettings *touchpad_settings)
+get_touchpad_enabled (GSettings *settings)
 {
-	gboolean enabled;
+        GDesktopDeviceSendEvents send_events;
 
-	if (!touchpad_is_present())
+        send_events = g_settings_get_enum (settings, "send-events");
+
+        return send_events == G_DESKTOP_DEVICE_SEND_EVENTS_ENABLED;
+}
+
+static gboolean
+show_touchpad_enabling_switch (CcMousePropertiesPrivate *d)
+{
+	if (!d->have_touchpad)
 		return FALSE;
 
 	/* Lets show the button when the mouse/touchscreen is present */
-	if (mouse_is_present() || touchscreen_is_present())
+	if (d->have_mouse || d->have_touchscreen)
 		return TRUE;
-	
+
 	/* Lets also show when touch pad is disabled. */
-	enabled = g_settings_get_boolean (touchpad_settings,  "touchpad-enabled");
-	if (!enabled)
+	if (!get_touchpad_enabled (d->touchpad_settings))
 		return TRUE;
-	
+
 	return FALSE;
 }
 
+static gboolean
+touchpad_enabled_get_mapping (GValue    *value,
+                              GVariant  *variant,
+                              gpointer   user_data)
+{
+        gboolean enabled;
+
+        enabled = g_strcmp0 (g_variant_get_string (variant, NULL), "enabled") == 0;
+        g_value_set_boolean (value, enabled);
+
+        return TRUE;
+}
+
+static GVariant *
+touchpad_enabled_set_mapping (const GValue              *value,
+                              const GVariantType        *type,
+                              gpointer                   user_data)
+{
+        gboolean enabled;
+
+        enabled = g_value_get_boolean (value);
+
+        return g_variant_new_string (enabled ? "enabled" : "disabled");
+}
+
 /* Set up the property editors in the dialog. */
 static void
 setup_dialog (CcMousePropertiesPrivate *d)
 {
 	GtkRadioButton *radio;
-	gboolean        touchpad_present, mouse_present;
 
 	/* Orientation radio buttons */
 	radio = GTK_RADIO_BUTTON (WID ("left_handed_radio"));
@@ -199,51 +228,50 @@ setup_dialog (CcMousePropertiesPrivate *d)
 		G_CALLBACK (orientation_radio_button_release_event), NULL);
 
 	/* Double-click time */
-	g_settings_bind (d->mouse_settings, "double-click",
+	g_settings_bind (d->gsd_mouse_settings, "double-click",
 			 gtk_range_get_adjustment (GTK_RANGE (WID ("double_click_scale"))), "value",
 			 G_SETTINGS_BIND_DEFAULT);
 
 	/* Mouse section */
-	mouse_present = mouse_is_present ();
-	gtk_widget_set_visible (WID ("mouse_vbox"), mouse_present);
+	gtk_widget_set_visible (WID ("mouse_vbox"), d->have_mouse);
 
-	g_settings_bind (d->mouse_settings, "motion-acceleration",
+	gtk_scale_add_mark (GTK_SCALE (WID ("pointer_speed_scale")), 0,
+			    GTK_POS_TOP, NULL);
+	g_settings_bind (d->mouse_settings, "speed",
 			 gtk_range_get_adjustment (GTK_RANGE (WID ("pointer_speed_scale"))), "value",
 			 G_SETTINGS_BIND_DEFAULT);
 
-	g_signal_connect (WID ("pointer_speed_scale"), "value-changed",
-			  G_CALLBACK (pointer_speed_scale_event), d);
-
 	/* Trackpad page */
-	touchpad_present = touchpad_is_present ();
-	gtk_widget_set_visible (WID ("touchpad_vbox"), touchpad_present);
+	gtk_widget_set_visible (WID ("touchpad_vbox"), d->have_touchpad);
 	gtk_widget_set_visible (WID ("touchpad_enabled_switch"), 
-				show_touchpad_enabling_switch (d->touchpad_settings));
+				show_touchpad_enabling_switch (d));
 
-	g_settings_bind (d->touchpad_settings, "touchpad-enabled",
-			 WID ("touchpad_enabled_switch"), "active",
-			 G_SETTINGS_BIND_DEFAULT);
-	g_settings_bind (d->touchpad_settings, "touchpad-enabled",
-			 WID ("touchpad_options_box"), "sensitive",
-			 G_SETTINGS_BIND_GET);
+	g_settings_bind_with_mapping (d->touchpad_settings, "send-events",
+				      WID ("touchpad_enabled_switch"), "active",
+				      G_SETTINGS_BIND_DEFAULT,
+				      touchpad_enabled_get_mapping,
+				      touchpad_enabled_set_mapping,
+				      NULL, NULL);
+	g_settings_bind_with_mapping (d->touchpad_settings, "send-events",
+				      WID ("touchpad_options_box"), "sensitive",
+				      G_SETTINGS_BIND_GET,
+				      touchpad_enabled_get_mapping,
+				      touchpad_enabled_set_mapping,
+				      NULL, NULL);
 
-	g_settings_bind (d->touchpad_settings, "disable-while-typing",
-			 WID ("disable_w_typing_toggle"), "active",
-			 G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind (d->touchpad_settings, "tap-to-click",
 			 WID ("tap_to_click_toggle"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind (d->touchpad_settings, "natural-scroll",
 			 WID ("natural_scroll_toggle"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
-	g_settings_bind (d->touchpad_settings, "motion-acceleration",
+	gtk_scale_add_mark (GTK_SCALE (WID ("touchpad_pointer_speed_scale")), 0,
+			    GTK_POS_TOP, NULL);
+	g_settings_bind (d->touchpad_settings, "speed",
 			 gtk_range_get_adjustment (GTK_RANGE (WID ("touchpad_pointer_speed_scale"))), "value",
 			 G_SETTINGS_BIND_DEFAULT);
 
-	g_signal_connect (WID ("touchpad_pointer_speed_scale"), "value-changed",
-			  G_CALLBACK (pointer_speed_scale_event), d);
-
-	if (touchpad_present) {
+	if (d->have_touchpad) {
 		synaptics_check_capabilities (d);
 		setup_scrollmethod_radios (d);
 	}
@@ -280,27 +308,37 @@ create_dialog (CcMousePropertiesPrivate *d)
 
 /* Callback issued when a button is clicked on the dialog */
 
+static gboolean
+have_device_type (GsdDeviceManager *manager,
+		  GsdDeviceType type)
+{
+	GList *l;
+
+	l = gsd_device_manager_list_devices (manager, type);
+	g_list_free (l);
+
+	return l != NULL;
+}
+
 static void
-device_changed (GdkDeviceManager *device_manager,
-		GdkDevice *device,
+device_changed (GsdDeviceManager *device_manager,
+		GsdDevice *device,
 		CcMousePropertiesPrivate *d)
 {
-	gboolean present;
+	d->have_touchpad = have_device_type (d->device_manager, GSD_DEVICE_TYPE_TOUCHPAD);
+	gtk_widget_set_visible (WID ("touchpad_vbox"), d->have_touchpad);
 
-	present = touchpad_is_present ();
-	gtk_widget_set_visible (WID ("touchpad_vbox"), present);
-
-	if (present) {
+	if (d->have_touchpad) {
 		d->changing_scroll = TRUE;
 		synaptics_check_capabilities (d);
 		setup_scrollmethod_radios (d);
 		d->changing_scroll = FALSE;
 	}
 
-	present = mouse_is_present ();
-	gtk_widget_set_visible (WID ("mouse_vbox"), present);
+	d->have_mouse = have_device_type (d->device_manager, GSD_DEVICE_TYPE_MOUSE);
+	gtk_widget_set_visible (WID ("mouse_vbox"), d->have_mouse);
 	gtk_widget_set_visible (WID ("touchpad_enabled_switch"), 
-				show_touchpad_enabling_switch (d->touchpad_settings));
+				show_touchpad_enabling_switch (d));
 }
 
 
@@ -310,6 +348,7 @@ cc_mouse_properties_finalize (GObject *object)
 	CcMousePropertiesPrivate *d = CC_MOUSE_PROPERTIES (object)->priv;
 
 	g_clear_object (&d->mouse_settings);
+	g_clear_object (&d->gsd_mouse_settings);
 	g_clear_object (&d->touchpad_settings);
 	g_clear_object (&d->builder);
 
@@ -346,15 +385,20 @@ cc_mouse_properties_init (CcMouseProperties *object)
 				       "/org/gnome/control-center/mouse/gnome-mouse-properties.ui",
 				       &error);
 
-	d->mouse_settings = g_settings_new ("org.gnome.settings-daemon.peripherals.mouse");
-	d->touchpad_settings = g_settings_new ("org.gnome.settings-daemon.peripherals.touchpad");
+	d->mouse_settings = g_settings_new ("org.gnome.desktop.peripherals.mouse");
+	d->gsd_mouse_settings = g_settings_new ("org.gnome.settings-daemon.peripherals.mouse");
+	d->touchpad_settings = g_settings_new ("org.gnome.desktop.peripherals.touchpad");
 
-	d->device_manager = gdk_display_get_device_manager (gdk_display_get_default ());
+	d->device_manager = gsd_device_manager_get ();
 	d->device_added_id = g_signal_connect (d->device_manager, "device-added",
 					       G_CALLBACK (device_changed), d);
 	d->device_removed_id = g_signal_connect (d->device_manager, "device-removed",
 						 G_CALLBACK (device_changed), d);
 
+	d->have_mouse = have_device_type (d->device_manager, GSD_DEVICE_TYPE_MOUSE);
+	d->have_touchpad = have_device_type (d->device_manager, GSD_DEVICE_TYPE_TOUCHPAD);
+	d->have_touchscreen = have_device_type (d->device_manager, GSD_DEVICE_TYPE_TOUCHSCREEN);
+
 	d->changing_scroll = FALSE;
 
 	gtk_container_add (GTK_CONTAINER (object), WID ("prefs_widget"));
