@@ -175,7 +175,7 @@ add_address_row (CEPageIP4   *page,
 
         row_grid = gtk_grid_new ();
         label = gtk_label_new (_("Address"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 1, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -188,7 +188,7 @@ add_address_row (CEPageIP4   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 1, 1, 1);
 
         label = gtk_label_new (_("Netmask"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 2, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -202,7 +202,7 @@ add_address_row (CEPageIP4   *page,
 
 
         label = gtk_label_new (_("Gateway"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 3, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -341,7 +341,7 @@ add_dns_row (CEPageIP4   *page,
 
         row_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         label = gtk_label_new (_("Server"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_box_pack_start (GTK_BOX (row_box), label, FALSE, FALSE, 0);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -437,7 +437,7 @@ add_route_row (CEPageIP4   *page,
 
         row_grid = gtk_grid_new ();
         label = gtk_label_new (_("Address"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 1, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -450,7 +450,7 @@ add_route_row (CEPageIP4   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 1, 1, 1);
 
         label = gtk_label_new (_("Netmask"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 2, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -463,7 +463,7 @@ add_route_row (CEPageIP4   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 2, 1, 1);
 
         label = gtk_label_new (_("Gateway"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 3, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -477,7 +477,7 @@ add_route_row (CEPageIP4   *page,
 
         /* Translators: Please see https://en.wikipedia.org/wiki/Metrics_(networking) */
         label = gtk_label_new (C_("network parameters", "Metric"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 4, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -625,7 +625,6 @@ connect_ip4_page (CEPageIP4 *page)
                                            -1);
 
         gtk_combo_box_set_model (page->method, GTK_TREE_MODEL (store));
-        g_object_unref (G_OBJECT (store));
 
         method = IP4_METHOD_AUTO;
         if (g_strcmp0 (str_method, NM_SETTING_IP4_CONFIG_METHOD_LINK_LOCAL) == 0) {
@@ -705,11 +704,7 @@ ui_to_setting (CEPageIP4 *page)
         }
 
         addresses = g_ptr_array_new_with_free_func (free_addr);
-        if (g_str_equal (method, NM_SETTING_IP4_CONFIG_METHOD_MANUAL))
-                children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
-        else
-                children = NULL;
-
+        children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
@@ -779,12 +774,7 @@ ui_to_setting (CEPageIP4 *page)
         }
 
         dns_servers = g_array_new (FALSE, FALSE, sizeof (guint));
-        if (g_str_equal (method, NM_SETTING_IP4_CONFIG_METHOD_AUTO) ||
-            g_str_equal (method, NM_SETTING_IP4_CONFIG_METHOD_MANUAL))
-                children = gtk_container_get_children (GTK_CONTAINER (page->dns_list));
-        else
-                children = NULL;
-
+        children = gtk_container_get_children (GTK_CONTAINER (page->dns_list));
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
@@ -812,13 +802,9 @@ ui_to_setting (CEPageIP4 *page)
         }
         g_list_free (children);
 
-        routes = g_ptr_array_new_with_free_func (free_addr);
-        if (g_str_equal (method, NM_SETTING_IP4_CONFIG_METHOD_AUTO) ||
-            g_str_equal (method, NM_SETTING_IP4_CONFIG_METHOD_MANUAL))
-                children = gtk_container_get_children (GTK_CONTAINER (page->routes_list));
-        else
-                children = NULL;
 
+        routes = g_ptr_array_new_with_free_func (free_addr);
+        children = gtk_container_get_children (GTK_CONTAINER (page->routes_list));
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
