@@ -522,6 +522,7 @@ add_device (CcPowerPanel *panel, UpDevice *device)
   gchar *name;
   gchar *s;
   gboolean show_caution = FALSE;
+  gboolean is_present;
 
   name = NULL;
   g_object_get (device,
@@ -529,8 +530,15 @@ add_device (CcPowerPanel *panel, UpDevice *device)
                 "percentage", &percentage,
                 "state", &state,
                 "model", &name,
+                "is-present", &is_present,
                 NULL);
 
+  if (!is_present)
+    {
+      g_free (name);
+      return;
+    }
+
   if (kind == UP_DEVICE_KIND_UPS)
     show_caution = TRUE;
 
@@ -1562,7 +1570,7 @@ add_power_saving_section (CcPowerPanel *self)
   gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
   gtk_box_pack_start (GTK_BOX (box2), label, TRUE, TRUE, 0);
 
-  w = gtk_label_new (_("Turns off wireless devices"));
+  w = gtk_label_new (_("Wireless devices require extra power"));
   gtk_widget_set_halign (w, GTK_ALIGN_START);
   gtk_style_context_add_class (gtk_widget_get_style_context (w), GTK_STYLE_CLASS_DIM_LABEL);
   gtk_box_pack_start (GTK_BOX (box2), w, TRUE, TRUE, 0);
@@ -1592,7 +1600,7 @@ add_power_saving_section (CcPowerPanel *self)
   gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
   gtk_box_pack_start (GTK_BOX (box2), label, TRUE, TRUE, 0);
 
-  w = gtk_label_new (_("Turns off mobile broadband (3G, 4G, WiMax, etc.) devices"));
+  w = gtk_label_new (_("Mobile broadband (3G, 4G, WiMax, etc.) devices require extra power"));
   gtk_widget_set_halign (w, GTK_ALIGN_START);
   gtk_style_context_add_class (gtk_widget_get_style_context (w), GTK_STYLE_CLASS_DIM_LABEL);
   gtk_box_pack_start (GTK_BOX (box2), w, TRUE, TRUE, 0);
@@ -1663,6 +1671,8 @@ add_power_saving_section (CcPowerPanel *self)
 				G_CALLBACK (bt_powered_state_changed), self);
       g_signal_connect (G_OBJECT (priv->bt_switch), "notify::active",
 			G_CALLBACK (bt_switch_changed), self);
+
+      bt_powered_state_changed (self);
     }
 #endif
 
