@@ -224,6 +224,9 @@ region_widget_new (const gchar *locale_id,
         GtkWidget *check;
 
         locale_name = gnome_get_country_from_locale (locale_id, locale_id);
+        if (!locale_name)
+          return NULL;
+
         locale_current_name = gnome_get_country_from_locale (locale_id, NULL);
         locale_untranslated_name = gnome_get_country_from_locale (locale_id, "C");
 
@@ -270,7 +273,6 @@ more_widget_new (void)
         gtk_style_context_add_class (gtk_widget_get_style_context (arrow), "dim-label");
         gtk_widget_set_margin_top (box, 10);
         gtk_widget_set_margin_bottom (box, 10);
-        gtk_misc_set_alignment (GTK_MISC (arrow), 0.5, 0.5);
         gtk_box_pack_start (GTK_BOX (box), arrow, TRUE, TRUE, 0);
 
         return GTK_LIST_BOX_ROW (row);
@@ -308,6 +310,9 @@ add_regions (GtkDialog   *chooser,
 
                 is_initial = (g_hash_table_lookup (initial, locale_id) != NULL);
                 widget = region_widget_new (locale_id, !is_initial);
+                if (!widget)
+                  continue;
+
                 gtk_container_add (GTK_CONTAINER (priv->list), widget);
         }
 
