@@ -67,6 +67,8 @@ typedef struct {
   gboolean showing_extra;
   guint filter_timeout_id;
   gchar **filter_words;
+
+  gboolean is_login;
 } CcInputChooserPrivate;
 
 #define GET_PRIVATE(chooser) ((CcInputChooserPrivate *) g_object_get_data (G_OBJECT (chooser), "private"))
@@ -119,14 +121,14 @@ padded_label_new (const gchar        *text,
   GtkWidget *widget;
   GtkWidget *label;
   GtkWidget *arrow;
-  gdouble alignment;
+  GtkAlign alignment;
 
   if (position == ROW_LABEL_POSITION_START)
-    alignment = 0.0;
+    alignment = GTK_ALIGN_START;
   else if (position == ROW_LABEL_POSITION_CENTER)
-    alignment = 0.5;
+    alignment = GTK_ALIGN_CENTER;
   else
-    alignment = 1.0;
+    alignment = GTK_ALIGN_END;
 
   widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
@@ -137,7 +139,7 @@ padded_label_new (const gchar        *text,
     }
 
   label = gtk_label_new (text);
-  gtk_misc_set_alignment (GTK_MISC (label), alignment, 0.5);
+  gtk_widget_set_halign (label, alignment);
   set_row_widget_margins (label);
   gtk_box_pack_start (GTK_BOX (widget), label, TRUE, TRUE, 0);
   if (dim_label)
@@ -167,7 +169,6 @@ more_row_new (void)
   arrow = gtk_image_new_from_icon_name ("view-more-symbolic", GTK_ICON_SIZE_MENU);
   gtk_style_context_add_class (gtk_widget_get_style_context (arrow), "dim-label");
   set_row_widget_margins (arrow);
-  gtk_misc_set_alignment (GTK_MISC (arrow), 0.5, 0.5);
   gtk_box_pack_start (GTK_BOX (box), arrow, TRUE, TRUE, 0);
 
   return GTK_LIST_BOX_ROW (row);
@@ -883,7 +884,7 @@ get_ibus_locale_infos (GtkWidget *chooser)
   const gchar *engine_id;
   IBusEngineDesc *engine;
 
-  if (!priv->ibus_engines)
+  if (!priv->ibus_engines || priv->is_login)
     return;
 
   g_hash_table_iter_init (&iter, priv->ibus_engines);
@@ -897,7 +898,7 @@ get_ibus_locale_infos (GtkWidget *chooser)
           lang_code != NULL &&
           country_code != NULL)
         {
-          gchar *locale = g_strdup_printf ("%s_%s.utf8", lang_code, country_code);
+          gchar *locale = g_strdup_printf ("%s_%s.UTF-8", lang_code, country_code);
 
           info = g_hash_table_lookup (priv->locales, locale);
           if (info)
@@ -1023,9 +1024,9 @@ get_locale_infos (GtkWidget *chooser)
         continue;
 
       if (country_code != NULL)
-	simple_locale = g_strdup_printf ("%s_%s.utf8", lang_code, country_code);
+	simple_locale = g_strdup_printf ("%s_%s.UTF-8", lang_code, country_code);
       else
-	simple_locale = g_strdup_printf ("%s.utf8", lang_code);
+	simple_locale = g_strdup_printf ("%s.UTF-8", lang_code);
 
       if (g_hash_table_contains (priv->locales, simple_locale))
         {
@@ -1117,6 +1118,7 @@ cc_input_chooser_private_free (gpointer data)
 
 GtkWidget *
 cc_input_chooser_new (GtkWindow    *main_window,
+                      gboolean      is_login,
                       GnomeXkbInfo *xkb_info,
                       GHashTable   *ibus_engines)
 {
@@ -1139,6 +1141,7 @@ cc_input_chooser_new (GtkWindow    *main_window,
   g_object_set_data_full (G_OBJECT (chooser), "private", priv, cc_input_chooser_private_free);
   g_object_set_data_full (G_OBJECT (chooser), "builder", builder, g_object_unref);
 
+  priv->is_login = is_login;
   priv->xkb_info = xkb_info;
   priv->ibus_engines = ibus_engines;
 
@@ -1160,6 +1163,9 @@ cc_input_chooser_new (GtkWindow    *main_window,
 
   g_signal_connect_swapped (priv->filter_entry, "search-changed", G_CALLBACK (filter_changed), chooser);
 
+  if (priv->is_login)
+    gtk_widget_show (WID ("login-label"));
+
   get_locale_infos (chooser);
 #ifdef HAVE_IBUS
   get_ibus_locale_infos (chooser);
